Examples / Tutorials
=====================

We've included 3 examples / tutorials to illustrate how you can use xGPR
for fixed-vector data, protein sequence data and small molecule data
as below. A fourth example illustrates how to build a custom dataloader
/ Dataset object that wraps a csv file, SQLite db or HDF5 file for
easy and convenient training.

.. toctree::
  :maxdepth: 1

  tabular_example

  sequence_example
  
  molecule_example

  custom_dataset_example
